
package org.infiltech;

import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.Callback;
import android.support.v4.content.ContextCompat;
import android.support.v4.app.ActivityCompat;

import com.facebook.react.bridge.NativeModule;
import android.widget.Toast;
import java.util.Map;
import java.util.HashMap;
import android.annotation.TargetApi;
import android.support.annotation.NonNull;

import android.os.Build;
import android.os.Bundle;

import android.Manifest;
import android.content.pm.PackageManager;

public class RNEasyArModule extends ReactContextBaseJavaModule {

  private final ReactApplicationContext reactContext;
  private static final String DURATION_SHORT_KEY = "SHORT";
  private static final String DURATION_LONG_KEY = "LONG";

  public RNEasyArModule(ReactApplicationContext reactContext) {
    super(reactContext);
    this.reactContext = reactContext;
  }

  @Override
  public String getName() {
    return "RNEasyAr";
  }

  @Override
  public Map<String, Object> getConstants() {
    final Map<String, Object> constants = new HashMap<>();
    constants.put(DURATION_SHORT_KEY, Toast.LENGTH_SHORT);
    constants.put(DURATION_LONG_KEY, Toast.LENGTH_LONG);
    return constants;
  }

  @ReactMethod
  public void show(String message, int duration) {
    Toast.makeText(getReactApplicationContext(), message, duration).show();
    requestCameraPermission(new PermissionCallback() {
      @Override
      public void onSuccess() {
        System.out.println("abc");
      }

      @Override
      public void onFailure() {
      }
    });
  }

  private interface PermissionCallback {
    void onSuccess();

    void onFailure();
  }

  private HashMap<Integer, PermissionCallback> permissionCallbacks = new HashMap<Integer, PermissionCallback>();
  private int permissionRequestCodeSerial = 0;

  @TargetApi(23)
  private void requestCameraPermission(PermissionCallback callback) {
    if (Build.VERSION.SDK_INT >= 23) {
      if (ContextCompat.checkSelfPermission(Manifest.permission.CAMERA) != PackageManager.PERMISSION_GRANTED) {
        int requestCode = permissionRequestCodeSerial;
        permissionRequestCodeSerial += 1;
        permissionCallbacks.put(requestCode, callback);
        ActivityCompat.requestPermissions(new String[] { Manifest.permission.CAMERA }, requestCode);
      } else {
        callback.onSuccess();
      }
    } else {
      callback.onSuccess();
    }
  }

  @Override
  public void onRequestPermissionsResult(int requestCode, @NonNull String[] permissions, @NonNull int[] grantResults) {
    if (permissionCallbacks.containsKey(requestCode)) {
      PermissionCallback callback = permissionCallbacks.get(requestCode);
      permissionCallbacks.remove(requestCode);
      boolean executed = false;
      for (int result : grantResults) {
        if (result != PackageManager.PERMISSION_GRANTED) {
          executed = true;
          callback.onFailure();
        }
      }
      if (!executed) {
        callback.onSuccess();
      }
    }
    super.onRequestPermissionsResult(requestCode, permissions, grantResults);
  }
}